@@ -22,9 +22,6 @@ pub(crate) enum IgdError {
     #[error("IGD is not supported for IPv6")]
     NotSupported,
 
-    #[error(transparent)]
-    AddAnyPort(#[from] igd::AddAnyPortError),
-
     #[error(transparent)]
     AddPort(#[from] igd::AddPortError),
 
@@ -32,8 +29,6 @@ pub(crate) enum IgdError {
     Search(#[from] igd::SearchError),
 }
 
-impl IgdError {}
-
 /// Automatically forwards a port and setups a tokio task to renew it periodically.
 pub(crate) async fn forward_port(
     ext_port: u16,
@@ -84,7 +79,7 @@ pub(crate) async fn add_port(
 
     debug!("IGD gateway found: {:?}", gateway);
 
-    debug!("Our local address is: {:?}", local_addr);
+    debug!("Adding port mapping for {} -> {}", ext_port, local_addr);
 
     let local_addr = match local_addr {
         SocketAddr::V4(local_addr) => local_addr,
